@@ -24,9 +24,9 @@
 mod app;
 mod config;
 pub mod invidious;
-mod lyric;
 mod player;
 mod song;
+mod songtag;
 mod ui;
 
 use anyhow::{anyhow, Result};
