@@ -22,16 +22,13 @@
  * SOFTWARE.
  */
 use super::{MainActivity, COMPONENT_TREEVIEW};
-
-// use spinners::{Spinner, Spinners};
 use anyhow::{bail, Result};
+use pinyin::{to_pinyin_vec, Pinyin};
 use std::fs::{remove_dir_all, remove_file, rename};
-use std::path::{Path, PathBuf};
-use std::thread;
+use std::path::Path;
 use tui_realm_treeview::{Node, Tree, TreeViewPropsBuilder};
 use tuirealm::event::{Event, KeyCode, KeyEvent, KeyModifiers};
 use tuirealm::{Payload, PropsBuilder, Value};
-use ytd_rs::{Arg, ResultType, YoutubeDL};
 
 impl MainActivity {
     pub fn scan_dir(&mut self, p: &Path) {
@@ -50,9 +47,18 @@ impl MainActivity {
         };
         let mut node: Node = Node::new(p.to_string_lossy().into_owned(), name);
         if depth > 0 && p.is_dir() {
-            if let Ok(e) = std::fs::read_dir(p) {
-                e.flatten()
-                    .for_each(|x| node.add_child(Self::dir_tree(x.path().as_path(), depth - 1)));
+            let mut paths: Vec<_> = std::fs::read_dir(p)
+                .unwrap()
+                .filter_map(|r| r.ok())
+                .collect();
+            // paths.sort_by_key(|dir| dir.path());
+            paths.sort_by(|a, b| {
+                get_pin_yin(&a.file_name().to_string_lossy().to_string())
+                    .cmp(&get_pin_yin(&b.file_name().to_string_lossy().to_string()))
+            });
+
+            for p in paths {
+                node.add_child(Self::dir_tree(p.path().as_path(), depth - 1));
             }
         }
         node
@@ -61,13 +67,20 @@ impl MainActivity {
     pub fn dir_children(p: &Path) -> Vec<String> {
         let mut children: Vec<String> = vec![];
         if p.is_dir() {
-            if let Ok(e) = std::fs::read_dir(p) {
-                e.flatten().for_each(|x| {
-                    if x.path().is_dir() {
-                    } else {
-                        children.push(String::from(x.path().to_string_lossy()));
-                    }
-                });
+            let mut paths: Vec<_> = std::fs::read_dir(p)
+                .unwrap()
+                .filter_map(|r| r.ok())
+                // .filter_map(|r| r.path().is_dir())
+                .collect();
+            paths.sort_by(|a, b| {
+                get_pin_yin(&a.file_name().to_string_lossy().to_string())
+                    .cmp(&get_pin_yin(&b.file_name().to_string_lossy().to_string()))
+            });
+
+            for p in paths {
+                if !p.path().is_dir() {
+                    children.push(String::from(p.path().to_string_lossy()));
+                }
             }
         }
         children
@@ -92,51 +105,6 @@ impl MainActivity {
         }
     }
 
-    pub fn youtube_dl(&mut self, link: &str) {
-        let mut path: PathBuf = PathBuf::new();
-        if let Some(Payload::One(Value::Str(node_id))) = self.view.get_state(COMPONENT_TREEVIEW) {
-            let p: &Path = Path::new(node_id.as_str());
-            if p.is_dir() {
-                path = PathBuf::from(p);
-            } else if let Some(p) = p.parent() {
-                path = p.to_path_buf();
-            }
-        }
-
-        let args = vec![
-            // Arg::new("--quiet"),
-            Arg::new("--extract-audio"),
-            Arg::new_with_arg("--audio-format", "mp3"),
-            Arg::new("--add-metadata"),
-            Arg::new("--embed-thumbnail"),
-            Arg::new_with_arg("--metadata-from-title", "%(artist) - %(title)s"),
-            Arg::new("--write-sub"),
-            Arg::new("--all-subs"),
-            Arg::new_with_arg("--convert-subs", "lrc"),
-            Arg::new_with_arg("--output", "%(title).90s.%(ext)s"),
-        ];
-        if let Ok(ytd) = YoutubeDL::new(&path, args, link) {
-            let tx = self.sender.clone();
-
-            thread::spawn(move || {
-                if tx.send(super::TransferState::Running).is_ok() {}
-                // start download
-                let download = ytd.download();
-
-                // check what the result is and print out the path to the download or the error
-                match download.result_type() {
-                    ResultType::SUCCESS => {
-                        if tx.send(super::TransferState::Completed(None)).is_ok() {}
-                    }
-                    ResultType::IOERROR | ResultType::FAILURE => {
-                        // println!("Couldn't start download: {}", download.output())
-                        if tx.send(super::TransferState::ErrDownload).is_ok() {}
-                    }
-                };
-            });
-        }
-    }
-
     pub fn delete_song(&mut self) -> Result<()> {
         if let Some(Payload::One(Value::Str(node_id))) = self.view.get_state(COMPONENT_TREEVIEW) {
             let p: &Path = Path::new(node_id.as_str());
@@ -209,3 +177,14 @@ impl MainActivity {
         Ok(())
     }
 }
+
+fn get_pin_yin(parma: &str) -> String {
+    let a = to_pinyin_vec(parma, Pinyin::plain).join("");
+    let mut b = a;
+    // let mut temp: String = String::new();
+    if b.is_empty() {
+        let temp = parma.to_lowercase();
+        b = temp;
+    }
+    b
+}
