@@ -31,11 +31,13 @@ use crate::song::Song;
 use crate::ui::keymap::*;
 use std::str::FromStr;
 // ext
-use humantime::format_duration;
-// use lrc::{Lyrics, TimeTag};
-use super::TransferState;
+use super::{StatusLine, TransferState};
 use crate::player::AudioPlayer;
+use crate::songtag::lrc::Lyric;
+use humantime::format_duration;
 use std::path::{Path, PathBuf};
+use std::thread;
+use std::thread::sleep;
 use std::time::Duration;
 use tui_realm_stdlib::{label, paragraph, progress_bar};
 use tui_realm_treeview::TreeViewPropsBuilder;
@@ -137,11 +139,12 @@ impl MainActivity {
                    if let Some(song) = self.current_song.as_mut(){
                    if let Some(lyric) = song.parsed_lyric.as_mut() {
                        lyric.adjust_offset(self.time_pos,1000);
-                       if let Some(song) = self.current_song.as_mut(){
+                           if let Some(text) = lyric.as_lrc_text() {
+                                song.set_lyric(&text,"Adjusted");
+                           }
                            if let Err(e) = song.save() {
                                self.mount_error(e.to_string().as_ref());
                            };
-                       };
                    }
                 }
                    None
@@ -152,11 +155,12 @@ impl MainActivity {
                     if let Some(song) = self.current_song.as_mut() {
                    if let Some(lyric) = song.parsed_lyric.as_mut() {
                        lyric.adjust_offset(self.time_pos,-1000);
-                       if let Some(song) = self.current_song.as_mut(){
+                            if let Some(text) = lyric.as_lrc_text() {
+                                   song.set_lyric(&text,"Adjusted");
+                           }
                            if let Err(e) = song.save() {
                                self.mount_error(e.to_string().as_ref());
                            };
-                       };
 
                    }
                 }
@@ -218,10 +222,9 @@ impl MainActivity {
                                 });
                                 self.view.on(event);
                             } else {
-                                let p = p.to_string_lossy();
-                                match Song::from_str(&p) {
+                                match Song::from_str(&p.to_string_lossy()) {
                                     Ok(s) => self.add_queue(s),
-                                    Err(e) => self.mount_error(e.to_string().as_ref()),
+                                    Err(e) => self.mount_error(&e.to_string()),
                                 };
                             }
                     }
@@ -323,7 +326,10 @@ impl MainActivity {
                 (COMPONENT_INPUT_URL, Msg::OnSubmit(Payload::One(Value::Str(url)))) => {
                         self.umount_youtube_url();
                         if url.starts_with("http") {
-                            self.youtube_dl(url);
+                            match self.youtube_dl(url) {
+                                Ok(_) => {}
+                                Err(e) => self.mount_error(format!("add queue error: {}",e).as_str()),
+                            }
                         } else {
                             self.mount_youtube_options();
                             self.youtube_options_search(url);
@@ -349,7 +355,9 @@ impl MainActivity {
                 (super::COMPONENT_SCROLLTABLE_YOUTUBE,key) if key== &MSG_KEY_ENTER => {
                     if let Some(Payload::One(Value::Usize(index))) = self.view.get_state(super::COMPONENT_SCROLLTABLE_YOUTUBE) {
                         // download from search result here
-                        self.youtube_options_download(index);
+                        if let Err(e) = self.youtube_options_download(index) {
+                            self.mount_error(format!("download song error: {}",e).as_str());
+                        }
                     }
                     self.umount_youtube_options();
                     None
@@ -410,6 +418,34 @@ impl MainActivity {
                     None
                 }
 
+                // switch lyrics
+                (_,key) if key == &MSG_KEY_CHAR_CAPITAL_T => {
+                    if let Some(mut song) = self.current_song.clone() {
+                        if song.lyric_frames.is_empty() {
+                            return None
+                        }
+                        song.lyric_selected +=1;
+                        if song.lyric_selected >= song.lyric_frames.len()  {
+                            song.lyric_selected = 0;
+                        }
+                        if let Some(f) = song.lyric_frames.get(song.lyric_selected) {
+                            if let Ok(parsed_lyric) = Lyric::from_str(&f.text) {
+                                let tx = self.sender_message.clone();
+                                song.parsed_lyric = Some(parsed_lyric);
+                                let lang_ext = f.description.clone();
+                                self.current_song = Some(song);
+                                thread::spawn(move || {
+                                    let _ = tx.send(super::MessageState::Show(("Lyric switch successful".to_string(),format!("{} lyric is showing",lang_ext))));
+                                    sleep(Duration::from_secs(5));
+                                    let _ = tx.send(super::MessageState::Hide);
+                                });
+                            }
+                        }
+                    }
+                    None
+                }
+
+
                 (COMPONENT_CONFIRMATION_RADIO,key) if key==  &MSG_KEY_ESC => {
                     self.umount_confirmation_radio();
                     None
@@ -469,7 +505,7 @@ impl MainActivity {
             return;
         }
 
-        if time_pos >= duration - 1 {
+        if time_pos >= duration {
             self.status = Some(Status::Stopped);
             return;
         }
@@ -546,7 +582,7 @@ impl MainActivity {
             return;
         };
 
-        let song = match self.current_song.clone() {
+        let song = match &self.current_song {
             Some(song) => song,
             None => return,
         };
@@ -591,14 +627,22 @@ impl MainActivity {
         if let Ok(transfer_state) = self.receiver.try_recv() {
             match transfer_state {
                 TransferState::Running => {
-                    self.update_status_line(false);
+                    self.update_status_line(StatusLine::Running);
                 }
-                TransferState::Completed(_file) => {
-                    self.update_status_line(true);
+                TransferState::Success => {
+                    self.update_status_line(StatusLine::Success);
+                }
+                TransferState::Completed(Some(file)) => {
+                    self.refresh_playlist(Some(file.as_str()));
+                    self.update_status_line(StatusLine::Default);
+                }
+                TransferState::Completed(None) => {
+                    self.refresh_playlist(None);
+                    self.update_status_line(StatusLine::Default);
                 }
                 TransferState::ErrDownload => {
                     self.mount_error("download failed");
-                    self.update_status_line(true);
+                    self.update_status_line(StatusLine::Error);
                 }
                 TransferState::ErrEmbedData => {
                     // This case will not happen in main activity
@@ -608,11 +652,10 @@ impl MainActivity {
     }
 
     // change status bar text to indicate the downloading state
-    pub fn update_status_line(&mut self, default_status_line: bool) {
-        match default_status_line {
-            true => {
+    pub fn update_status_line(&mut self, s: StatusLine) {
+        match s {
+            StatusLine::Default => {
                 let text = "Press \"?\" for help.".to_string();
-
                 if let Some(props) = self.view.get_props(super::COMPONENT_LABEL_HELP) {
                     let props = label::LabelPropsBuilder::from(props)
                         .with_text(text)
@@ -622,9 +665,10 @@ impl MainActivity {
 
                     let msg = self.view.update(super::COMPONENT_LABEL_HELP, props);
                     self.update(msg);
+                    self.redraw = true;
                 }
             }
-            false => {
+            StatusLine::Running => {
                 let text = " Downloading...".to_string();
 
                 if let Some(props) = self.view.get_props(super::COMPONENT_LABEL_HELP) {
@@ -636,6 +680,57 @@ impl MainActivity {
 
                     let msg = self.view.update(super::COMPONENT_LABEL_HELP, props);
                     self.update(msg);
+                    self.redraw = true;
+                }
+            }
+            StatusLine::Success => {
+                let text = " Download Success!".to_string();
+
+                if let Some(props) = self.view.get_props(super::COMPONENT_LABEL_HELP) {
+                    let props = label::LabelPropsBuilder::from(props)
+                        .with_text(text)
+                        .with_foreground(tuirealm::tui::style::Color::White)
+                        .with_background(tuirealm::tui::style::Color::Green)
+                        .build();
+
+                    let msg = self.view.update(super::COMPONENT_LABEL_HELP, props);
+                    self.update(msg);
+                    self.redraw = true;
+                }
+            }
+            StatusLine::Error => {
+                let text = " Download Error!".to_string();
+
+                if let Some(props) = self.view.get_props(super::COMPONENT_LABEL_HELP) {
+                    let props = label::LabelPropsBuilder::from(props)
+                        .with_text(text)
+                        .with_foreground(tuirealm::tui::style::Color::White)
+                        .with_background(tuirealm::tui::style::Color::Red)
+                        .build();
+
+                    let msg = self.view.update(super::COMPONENT_LABEL_HELP, props);
+                    self.update(msg);
+                    self.redraw = true;
+                }
+            }
+        }
+    }
+
+    // update message box
+    pub fn update_message(&mut self) {
+        if let Ok(message_state) = self.receiver_message.try_recv() {
+            match message_state {
+                super::MessageState::Show((title, text)) => {
+                    // if let Some(props) = self.view.get_props(super::COMPONENT_TEXT_MESSAGE) {
+                    //     if props.visible {
+                    //         self.umount_message();
+                    //     }
+                    // }
+
+                    self.mount_message(&title, &text);
+                }
+                super::MessageState::Hide => {
+                    self.umount_message();
                 }
             }
         }
