@@ -53,6 +53,8 @@ const COMPONENT_TE_INPUT_SONGNAME: &str = "INPUT_TE_SONGNAME";
 const COMPONENT_TE_RADIO_TAG: &str = "RADIO_TE_TAG";
 const COMPONENT_TE_SCROLLTABLE_OPTIONS: &str = "SCROLLTABLE_TE_OPTIONS";
 const COMPONENT_TE_TEXTAREA_LYRIC: &str = "TEXTAREA_TE_LYRIC";
+const COMPONENT_TE_SELECT_LYRIC: &str = "SELECT_TE_LYRIC";
+const COMPONENT_TE_DELETE_LYRIC: &str = "DELETE_TE_LYRIC";
 
 /// ### ViewLayout
 ///
