@@ -24,7 +24,7 @@ use super::SearchLyricState;
  */
 // locals
 use super::{TagEditorActivity, COMPONENT_TE_LABEL_HELP};
-use crate::ui::activity::main::TransferState;
+use crate::ui::activity::main::{StatusLine, TransferState};
 use crate::ui::keymap::*;
 // use crate::ui::components::scrolltable;
 use super::ExitReason;
@@ -62,9 +62,20 @@ impl TagEditorActivity {
                 }
 
                 (super::COMPONENT_TE_SCROLLTABLE_OPTIONS, key) if key == &MSG_KEY_TAB => {
+                    self.view.active(super::COMPONENT_TE_SELECT_LYRIC);
+                    None
+                }
+
+                (super::COMPONENT_TE_SELECT_LYRIC, key) if key == &MSG_KEY_TAB => {
+                    self.view.active(super::COMPONENT_TE_DELETE_LYRIC);
+                    None
+                }
+
+                (super::COMPONENT_TE_DELETE_LYRIC, key) if key == &MSG_KEY_TAB => {
                     self.view.active(super::COMPONENT_TE_TEXTAREA_LYRIC);
                     None
                 }
+
                 (super::COMPONENT_TE_TEXTAREA_LYRIC, key) if key == &MSG_KEY_TAB => {
                     self.view.active(super::COMPONENT_TE_RADIO_TAG);
                     None
@@ -133,33 +144,29 @@ impl TagEditorActivity {
                                     song.album = Some(album.to_owned());
                                 }
 
-                                match song_tag.fetch_lyric() {
-                                    Ok(lyric_string) => {
-                                        song.set_lyric(lyric_string, lang_ext);
-                                        if let Ok(artwork) = song_tag.fetch_photo() {
-                                            song.set_photo(artwork);
-                                        }
-                                        match song.save() {
-                                            Ok(()) => {
-                                                match song.rename_by_tag() {
-                                                    Ok(()) => {
-                                                        if let Some(file) = song.file() {
-                                                            self.exit_reason = Some(
-                                                                ExitReason::NeedRefreshPlaylist(
-                                                                    file.to_string(),
-                                                                ),
-                                                            );
-                                                        }
-                                                        self.init_by_song(&song)
-                                                    }
-                                                    Err(e) => self.mount_error(&e.to_string()),
-                                                };
-                                            }
-                                            Err(e) => self.mount_error(&e.to_string()),
-                                        }
+                                if let Ok(lyric_string) = song_tag.fetch_lyric() {
+                                    song.set_lyric(&lyric_string, &lang_ext);
+                                    if let Ok(artwork) = song_tag.fetch_photo() {
+                                        song.set_photo(artwork);
                                     }
-                                    Err(e) => self.mount_error(&e.to_string()),
-                                };
+                                    match song.save() {
+                                        Ok(()) => {
+                                            match song.rename_by_tag() {
+                                                Ok(()) => {
+                                                    if let Some(file) = song.file() {
+                                                        self.exit_reason =
+                                                            Some(ExitReason::NeedRefreshPlaylist(
+                                                                file.to_string(),
+                                                            ));
+                                                    }
+                                                    self.init_by_song(&song)
+                                                }
+                                                Err(e) => self.mount_error(&e.to_string()),
+                                            };
+                                        }
+                                        Err(e) => self.mount_error(&e.to_string()),
+                                    }
+                                }
                             }
 
                             None
@@ -186,6 +193,43 @@ impl TagEditorActivity {
                     None
                 }
 
+                // select lyric
+                (
+                    super::COMPONENT_TE_SELECT_LYRIC,
+                    Msg::OnSubmit(Payload::One(Value::Usize(index))),
+                ) => {
+                    if let Some(mut song) = self.song.clone() {
+                        song.lyric_selected = *index;
+                        self.init_by_song(&song);
+                        self.song = Some(song);
+                    }
+                    None
+                }
+
+                // delete lyric
+                (super::COMPONENT_TE_DELETE_LYRIC, key) if key == &MSG_KEY_ENTER => {
+                    if let Some(mut song) = self.song.take() {
+                        if song.lyric_frames.is_empty() {
+                            song.parsed_lyric = None;
+                            return None;
+                        }
+                        song.lyric_frames.remove(song.lyric_selected as usize);
+                        if (song.lyric_selected as usize >= song.lyric_frames.len())
+                            && (song.lyric_selected > 0)
+                        {
+                            song.lyric_selected -= 1;
+                        }
+                        match song.save() {
+                            Ok(_) => {
+                                self.init_by_song(&song);
+                                self.song = Some(song);
+                            }
+                            Err(e) => self.mount_error(&e.to_string()),
+                        }
+                    }
+                    None
+                }
+
                 (super::COMPONENT_TE_INPUT_ARTIST, Msg::OnSubmit(Payload::One(Value::Str(_))))
                 | (
                     super::COMPONENT_TE_INPUT_SONGNAME,
@@ -329,7 +373,10 @@ impl TagEditorActivity {
         if let Ok(transfer_state) = self.receiver.try_recv() {
             match transfer_state {
                 TransferState::Running => {
-                    self.update_status_line(false);
+                    self.update_status_line(StatusLine::Running);
+                }
+                TransferState::Success => {
+                    self.update_status_line(StatusLine::Success);
                 }
                 TransferState::Completed(file) => {
                     if let Some(f) = file {
@@ -340,15 +387,15 @@ impl TagEditorActivity {
                             self.init_by_song(&song1);
                         }
                     }
-                    self.update_status_line(true);
+                    self.update_status_line(StatusLine::Default);
                 }
                 TransferState::ErrDownload => {
                     self.mount_error("download failed");
-                    self.update_status_line(true);
+                    self.update_status_line(StatusLine::Error);
                 }
                 TransferState::ErrEmbedData => {
                     self.mount_error("download ok but tag info is not complete.");
-                    self.update_status_line(true);
+                    self.update_status_line(StatusLine::Error);
                 }
             }
         };
@@ -360,9 +407,9 @@ impl TagEditorActivity {
             self.redraw = true;
         }
     }
-    pub fn update_status_line(&mut self, default_status_line: bool) {
-        match default_status_line {
-            true => {
+    pub fn update_status_line(&mut self, s: StatusLine) {
+        match s {
+            StatusLine::Default => {
                 let text = "Press \"?\" for help.".to_string();
 
                 if let Some(props) = self.view.get_props(COMPONENT_TE_LABEL_HELP) {
@@ -383,9 +430,39 @@ impl TagEditorActivity {
                     self.redraw = true;
                 }
             }
-            false => {
+            StatusLine::Running => {
                 let text = " Downloading...".to_string();
 
+                if let Some(props) = self.view.get_props(COMPONENT_TE_LABEL_HELP) {
+                    let props = label::LabelPropsBuilder::from(props)
+                        .with_text(text)
+                        .with_foreground(Color::White)
+                        .with_background(Color::Red)
+                        .build();
+
+                    let msg = self.view.update(COMPONENT_TE_LABEL_HELP, props);
+                    self.update(msg);
+                    self.redraw = true;
+                }
+            }
+            StatusLine::Success => {
+                let text = " Download Success!".to_string();
+
+                if let Some(props) = self.view.get_props(COMPONENT_TE_LABEL_HELP) {
+                    let props = label::LabelPropsBuilder::from(props)
+                        .with_text(text)
+                        .with_foreground(Color::Black)
+                        .with_background(Color::Green)
+                        .build();
+
+                    let msg = self.view.update(COMPONENT_TE_LABEL_HELP, props);
+                    self.update(msg);
+                    self.redraw = true;
+                }
+            }
+            StatusLine::Error => {
+                let text = " Download Error!".to_string();
+
                 if let Some(props) = self.view.get_props(COMPONENT_TE_LABEL_HELP) {
                     let props = label::LabelPropsBuilder::from(props)
                         .with_text(text)
